pub enum ReShaderError {
Show 13 variants
FetchLatestVersion(String),
Download(String, String),
Symlink(String, String, String),
NoZipFile,
NoReShade64Dll,
ReadZipFile,
ExtractZipFile,
RepositoryNotFound(String),
BranchNotFound(String, String),
MergeConflict(String, String),
Io(Error),
Reqwest(Error),
Git(Error),
}
Errors that can occur when installing ReShade
Occurs when there is a problem fetching the latest ReShade version from GitHub
For example, if the GitHub API is down, this error will occur.
Occurs when there is a problem downloading a file
Additionally, the second argument is additional information about the error.
Occurs when there is a problem symlinking a file or a directory
Occurs when the ReShade installer doesn’t have a zip file (it’s missing its byte sequence for the zip file)
Occurs when the ReShade installer doesn’t have a ReShade64.dll file contained in it
Occurs when the ReShade installer’s zip file cannot be read
Occurs when the ReShade installer’s zip file cannot be extracted
Occurs when the repository for shaders or presets cannot be found
Occurs when the branch for shaders or presets cannot be found
Occurs when the branch for shaders or presets cannot be merged
Forwards the errors from std::io::Error
Forwards the errors from reqwest::Error
Forwards the errors from git2::Error
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
The lower-level source of this error, if any.
Read more
👎Deprecated since 1.42.0: use the Display impl or to_string()
👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type based access to context intended for error reports.
Read more
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more
Mutably dereferences the given pointer.
Read more
Drops the object pointed to by the given pointer.
Read more
🔬This is a nightly-only experimental API. (provide_any)
Data providers should implement this method to provide
all values they are able to
provide by using
demand.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.