Function reshaderlib::get_latest_reshade_version
source · pub async fn get_latest_reshade_version(
client: &Client,
version: Option<String>,
vanilla: bool
) -> ReShaderResult<String>Expand description
Fetches the latest ReShade version from GitHub.
Alternatively, if version is provided, it will return that version.
Please note that there is no check to see if the version is valid or not.