pub async fn install_presets(
    directory: &PathBuf,
    presets_path: &PathBuf,
    shaders_path: &PathBuf
) -> ReShaderResult<()>
Installs GShade presets and shaders to the given directory.

This does not download the presets and shaders, it just extracts them from the given zip files.